@@ -1,4 +1,5 @@
-# -*- coding: utf-8 -*-
+"""Module provides info about your instance and tools to switch roles and user."""
+
 from AccessControl.SecurityManagement import getSecurityManager
 from AccessControl.SecurityManagement import newSecurityManager
 from AccessControl.SecurityManagement import setSecurityManager
@@ -14,7 +15,6 @@ from plone.api.validation import mutually_exclusive_parameters
 from plone.api.validation import required_parameters
 from zope.globalrequest import getRequest
 
-import six
 import traceback
 import Zope2
 
@@ -22,8 +22,8 @@ import Zope2
 IS_TEST = None
 
 
-@at_least_one_of('username', 'user')
-@mutually_exclusive_parameters('username', 'user')
+@at_least_one_of("username", "user")
+@mutually_exclusive_parameters("username", "user")
 def adopt_user(username=None, user=None):
     """Context manager for temporarily switching user inside a block.
 
@@ -31,7 +31,7 @@ def adopt_user(username=None, user=None):
     :type user: user object from acl_users.getUser() or api.user.get().
     :param username: username of user to switch to inside block.
     :type username: string
-    :Example: :ref:`env_adopt_user_example`
+    :Example: :ref:`env-adopt-user-example`
     """
     # Grab the user object out of acl_users because this function
     # accepts 'user' objects that are actually things like MemberData
@@ -80,20 +80,21 @@ def _adopt_user(user):
     old_security_manager = getSecurityManager()
     newSecurityManager(getRequest(), user)
 
-    yield
-
-    setSecurityManager(old_security_manager)
+    try:
+        yield
+    finally:
+        setSecurityManager(old_security_manager)
 
 
-@required_parameters('roles')
+@required_parameters("roles")
 def adopt_roles(roles=None):
     """Context manager for temporarily switching roles.
 
     :param roles: New roles to gain inside block. Existing roles will be lost.
     :type roles: list of strings
-    :Example: :ref:`env_adopt_roles_example`
+    :Example: :ref:`env-adopt-roles-example`
     """
-    if isinstance(roles, six.string_types):
+    if isinstance(roles, str):
         roles = [roles]
 
     if not roles:
@@ -120,12 +121,13 @@ def _adopt_roles(roles):
     security_manager = getSecurityManager()
     security_manager.addContext(overriding_context)
 
-    yield
-
-    security_manager.removeContext(overriding_context)
+    try:
+        yield
+    finally:
+        security_manager.removeContext(overriding_context)
 
 
-class _GlobalRoleOverridingContext(object):
+class _GlobalRoleOverridingContext:
     # ZopeSecurityPolicy will use security_context._proxy_roles in place of
     # the roles that would normally be active, provided that it happens to
     # consider the security_context object to be relevant.
@@ -180,9 +182,9 @@ class _GlobalRoleOverridingContext(object):
 
 
 def debug_mode():
-    """Returns True if your zope instance is running in debug mode.
+    """Return True if your zope instance is running in debug mode.
 
-    :Example: :ref:`env_debug_mode_example`
+    :Example: :ref:`env-debug-mode-example`
     """
     return getConfiguration().debug_mode
 
@@ -190,14 +192,14 @@ def debug_mode():
 def test_mode():
     """Returns True if you are running the zope test runner.
 
-    :Example: :ref:`env_test_mode_example`
+    :Example: :ref:`env-test-mode-example`
     """
     global IS_TEST
 
     if IS_TEST is None:
         IS_TEST = False
         for frame in traceback.extract_stack():
-            if 'testrunner' in frame[0] or 'testreport/runner' in frame[0]:
+            if "testrunner" in frame[0] or "testreport/runner" in frame[0]:
                 IS_TEST = True
                 break
 
@@ -208,7 +210,7 @@ def read_only_mode():
     """Check if the Zope instance is running on a read-only ZODB.
 
     :returns: bool isReadOnly True if ZODB is read-only
-    :Example: :ref:`env_read_only_mode_example`
+    :Example: :ref:`env-read-only-mode-example`
     """
     with closing(Zope2.DB.open()) as connection:
         return connection.isReadOnly()
@@ -218,15 +220,15 @@ def plone_version():
     """Return Plone version number.
 
     :returns: string denoting what release of Plone this distribution contains
-    :Example: :ref:`env_plone_version_example`
+    :Example: :ref:`env-plone-version-example`
     """
-    return get_distribution('Products.CMFPlone').version
+    return get_distribution("Products.CMFPlone").version
 
 
 def zope_version():
     """Return Zope 2 version number.
 
     :returns: string denoting what release of Zope2 this distribution contains
-    :Example: :ref:`env_zope_version_example`
+    :Example: :ref:`env-zope-version-example`
     """
-    return get_distribution('Zope2').version
+    return get_distribution("Zope2").version
