@@ -1,5 +1,4 @@
-# -*- coding: utf-8 -*-
-"""Decorators for validating parameters"""
+"""Provide decorators for validating parameters."""
 
 from decorator import decorator
 from plone.api.exc import InvalidParameterError
@@ -9,18 +8,18 @@ import inspect
 
 
 def _get_arg_spec(func, validator_args):
-    """Get the arguments specified in the function spec
+    """Get the arguments specified in the function spec.
+
     and check that the decorator doesn't refer to non-existant args.
     """
-    signature_args, _, _, _ = inspect.getargspec(func)
-
+    signature_args = inspect.getfullargspec(func).args
     extra_args = set(validator_args) - set(signature_args)
     if extra_args:
         raise ValueError(
-            'Validator for {name} refers to parameters '
-            'that are not part of the function signature: {signature}'.format(
+            "Validator for {name} refers to parameters "
+            "that are not part of the function signature: {signature}".format(
                 name=func.__name__,
-                signature=', '.join(extra_args),
+                signature=", ".join(extra_args),
             ),
         )
 
@@ -28,7 +27,8 @@ def _get_arg_spec(func, validator_args):
 
 
 def _get_supplied_args(signature_params, args, kwargs):
-    """Return names of all args that have been passed in
+    """Return names of all args that have been passed in.
+
     either as positional or keyword arguments, and are not None.
     """
     supplied_args = []
@@ -44,8 +44,7 @@ def _get_supplied_args(signature_params, args, kwargs):
 
 
 def required_parameters(*required_params):
-    """A decorator that tests whether all of the specified parameters
-    have been supplied and are not None
+    """Test whether all of the specified parameters have been supplied and are not None.
 
     Todo: add an optional flag to allow None values through as valid parameters
 
@@ -54,23 +53,20 @@ def required_parameters(*required_params):
     def foo(a=None, b=None, c=None):
         pass
     """
+
     def _required_parameters(func):
-        """The actual decorator"""
+        """Provide actual decorator."""
         signature_params = _get_arg_spec(func, required_params)
 
         def wrapped(function, *args, **kwargs):
-            """The wrapped function (whose docstring will get replaced)"""
+            """Provide wrapped function (whose docstring will get replaced)."""
             supplied_args = _get_supplied_args(signature_params, args, kwargs)
 
-            missing = [
-                param
-                for param in required_params
-                if param not in supplied_args
-            ]
+            missing = [param for param in required_params if param not in supplied_args]
             if len(missing):
                 raise MissingParameterError(
-                    'Missing required parameter(s): {params}'.format(
-                        params=', '.join(missing),
+                    "Missing required parameter(s): {params}".format(
+                        params=", ".join(missing),
                     ),
                 )
 
@@ -82,7 +78,9 @@ def required_parameters(*required_params):
 
 
 def mutually_exclusive_parameters(*exclusive_params):
-    """A decorator that raises an exception if more than one
+    """Provide decorator.
+
+    The decorator raises an exception if more than one
     of the specified parameters has been supplied and is not None
 
     Usage:
@@ -90,22 +88,21 @@ def mutually_exclusive_parameters(*exclusive_params):
     def foo(a=None, b=None, c=None):
         pass
     """
+
     def _mutually_exclusive_parameters(func):
-        """The actual decorator."""
+        """Provide a decorator."""
         signature_params = _get_arg_spec(func, exclusive_params)
 
         def wrapped(function, *args, **kwargs):
-            """The wrapped function (whose docstring will get replaced)."""
+            """Provide a wrapped function (whose docstring will get replaced)."""
             supplied_args = _get_supplied_args(signature_params, args, kwargs)
             clashes = [
-                argument
-                for argument in supplied_args
-                if argument in exclusive_params
+                argument for argument in supplied_args if argument in exclusive_params
             ]
             if len(clashes) > 1:
                 raise InvalidParameterError(
-                    'These parameters are mutually exclusive: {arg}.'.format(
-                        arg=', '.join(supplied_args),
+                    "These parameters are mutually exclusive: {arg}.".format(
+                        arg=", ".join(clashes),
                     ),
                 )
 
@@ -117,7 +114,9 @@ def mutually_exclusive_parameters(*exclusive_params):
 
 
 def at_least_one_of(*candidate_params):
-    """A decorator that raises an exception if none of the
+    """Provide a decorator.
+
+    The decorator raises an exception if none of the
     specified parameters has been supplied.  Can be used in conjunction with
     mutually_exclusive_parameters to enforce exactly one.
 
@@ -126,12 +125,13 @@ def at_least_one_of(*candidate_params):
     def foo(a=None, b=None, c=None):
         pass
     """
+
     def _at_least_one_of(func):
-        """The actual decorator."""
+        """Provide an actual decorator."""
         signature_params = _get_arg_spec(func, candidate_params)
 
         def wrapped(function, *args, **kwargs):
-            """The wrapped function (whose docstring will get replaced)."""
+            """Provide a wrapped function (whose docstring will get replaced)."""
             supplied_args = _get_supplied_args(signature_params, args, kwargs)
             candidates = [
                 candidate
@@ -140,9 +140,9 @@ def at_least_one_of(*candidate_params):
             ]
             if len(candidates) < 1:
                 raise MissingParameterError(
-                    'At least one of these parameters must be '
-                    'supplied: {params}.'.format(
-                        params=', '.join(candidate_params),
+                    "At least one of these parameters must be "
+                    "supplied: {params}.".format(
+                        params=", ".join(candidate_params),
                     ),
                 )
 
